"""See LightDB docstring:

from LightDB import LightDB
---------------------

:copyright: (c) 2021-2022 by Fl1yd.
:license: MIT, see LICENSE for more details.
"""

__all__ = ["LightDB"]
__version__ = "1.3"

from .LightDB import LightDB
